==> neo4j-cypher-compiler-2.3-2.3.11-sources.jar: org/neo4j/cypher/internal/compiler/v2_3/planner/logical/plans/LetSemiApply.scala <==
/*
 * Copyright (c) 2002-2017 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.cypher.internal.compiler.v2_3.planner.logical.plans

import org.neo4j.cypher.internal.compiler.v2_3.planner.{CardinalityEstimation, PlannerQuery}

case class LetSemiApply(left: LogicalPlan, right: LogicalPlan, idName: IdName)
                       (val solved: PlannerQuery with CardinalityEstimation)
  extends AbstractLetSemiApply(left, right, idName, solved) with LogicalPlanWithoutExpressions

case class LetAntiSemiApply(left: LogicalPlan, right: LogicalPlan, idName: IdName)
                           (val solved: PlannerQuery with CardinalityEstimation)
  extends AbstractLetSemiApply(left, right, idName, solved) with LogicalPlanWithoutExpressions

abstract class AbstractLetSemiApply(left: LogicalPlan, right: LogicalPlan,
                                    idName: IdName, solved: PlannerQuery with CardinalityEstimation)
  extends LogicalPlan with LazyLogicalPlan {
  val lhs = Some(left)
  val rhs = Some(right)

  def availableSymbols = left.availableSymbols + idName
}

==> neo4j-cypher-compiler-3.0-3.0.3-sources.jar: org/neo4j/cypher/internal/compiler/v3_0/planner/logical/plans/LetSemiApply.scala <==
/*
 * Copyright (c) 2002-2016 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.cypher.internal.compiler.v3_0.planner.logical.plans

import org.neo4j.cypher.internal.compiler.v3_0.planner.{CardinalityEstimation, PlannerQuery}

case class LetSemiApply(left: LogicalPlan, right: LogicalPlan, idName: IdName)
                       (val solved: PlannerQuery with CardinalityEstimation)
  extends AbstractLetSemiApply(left, right, idName, solved)

case class LetAntiSemiApply(left: LogicalPlan, right: LogicalPlan, idName: IdName)
                           (val solved: PlannerQuery with CardinalityEstimation)
  extends AbstractLetSemiApply(left, right, idName, solved)

abstract class AbstractLetSemiApply(left: LogicalPlan, right: LogicalPlan,
                                    idName: IdName, solved: PlannerQuery with CardinalityEstimation)
  extends LogicalPlan with LazyLogicalPlan {
  val lhs = Some(left)
  val rhs = Some(right)

  def availableSymbols = left.availableSymbols + idName
}
